Skip to contents

A small example of single cell dataset used to demonstrate and test functions in the harf package.

Usage

data(single_cell)

Format

An object of class data.frame with 1652 rows and 81 columns.

Data derived from the RNAseqDB repository maintained by Memorial Sloan Kettering Cancer Center (https://github.com/mskcc/RNAseqDB).