R/kich.R
kich.Rd
A small example of the TCGA-KICH dataset used to demonstrate functions in the harf package.
kich
A data frame.
Data derived from The Cancer Genome Atlas Kidney Chromophobe Collection (TCGA-KICH).