R/single_cell.R
single_cell.Rd
A small example of single cell dataset used to demonstrate and test functions in the harf package.
harf
data(single_cell)
An object of class data.frame with 1652 rows and 81 columns.
data.frame
Data derived from the RNAseqDB repository maintained by Memorial Sloan Kettering Cancer Center (https://github.com/mskcc/RNAseqDB).